# HISTORY

## Unreleased

### Added

- Added `connect` function

## [v0.0.0 - 2022-06-26](https://github.com/se7entyse7en/ohmyfpg/compare/95f47c4cee38fad74a969ec34e5169c6e4e23c38...v0.0.0)

- Project inception! :tada:
